<?php
// 视频文件目录
$videoDir = 'videos/';

// 获取当前播放的文件名
$currentFile = isset($_GET['file']) ? $_GET['file'] : '';

// 获取目录中的视频文件列表
$videoFiles = array_diff(scandir($videoDir), array('.', '..'));

// 只处理 .mp4 文件
$videoFiles = array_filter($videoFiles, function ($file) use ($videoDir) {
    return pathinfo($videoDir . $file, PATHINFO_EXTENSION) === 'mp4';
});

// 自然排序文件列表
natcasesort($videoFiles);
$videoFiles = array_values($videoFiles); // 重新索引数组

// 找到当前文件的索引
$currentIndex = array_search($currentFile, $videoFiles);

// 设置上一集和下一集的链接
$prevFile = $currentIndex > 0 ? $videoFiles[$currentIndex - 1] : null;
$nextFile = $currentIndex < count($videoFiles) - 1 ? $videoFiles[$currentIndex + 1] : null;

if (!$currentFile || !file_exists($videoDir . $currentFile)) {
    die("视频文件不存在！");
}

$videoFile = $videoDir . $currentFile;
?>

<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>播放 <?php echo htmlspecialchars($currentFile); ?></title>
    <link rel="stylesheet" href="assets/style.css">
</head>
<body>
    <div class="container">
        <nav>
            <a href="index.php">🏠 首页</a>
        </nav>

        <h2>播放 <?php echo htmlspecialchars($currentFile); ?></h2>
        
        <video id="videoPlayer" width="100%" controls autoplay>
            <source src="<?php echo htmlspecialchars($videoFile); ?>" type="video/mp4">
            您的浏览器不支持 HTML5 视频标签。
        </video>

        <div class="controls">
            <!-- 上一集按钮 -->
            <?php if ($prevFile): ?>
                <a href="video.php?file=<?php echo urlencode($prevFile); ?>" class="prev-button">上一集</a>
            <?php else: ?>
                <button disabled class="prev-button">没有上一集</button>
            <?php endif; ?>

            <!-- 选集下拉菜单 -->
            <select id="episodeSelect" onchange="window.location.href = this.value;">
                <?php foreach ($videoFiles as $file): ?>
                    <option value="video.php?file=<?php echo urlencode($file); ?>"
                        <?php echo $file === $currentFile ? 'selected' : ''; ?>>
                        <?php echo pathinfo($file, PATHINFO_FILENAME); ?>
                    </option>
                <?php endforeach; ?>
            </select>

            <!-- 下一集按钮 -->
            <?php if ($nextFile): ?>
                <a href="video.php?file=<?php echo urlencode($nextFile); ?>" class="next-button">下一集</a>
            <?php else: ?>
                <button disabled class="next-button">没有下一集</button>
            <?php endif; ?>
        </div>
    </div>

    <style>
        .controls {
            margin-top: 20px;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        .prev-button, .next-button, select {
            padding: 10px;
            margin: 0 10px;
            background-color: #333;
            color: #fff;
            border: none;
            cursor: pointer;
            border-radius: 5px;
        }
        button[disabled] {
            background-color: #555;
            cursor: not-allowed;
        }
    </style>

    <script>
        // 获取视频元素
        const videoPlayer = document.getElementById('videoPlayer');

        // 当视频结束时自动播放下一集
        videoPlayer.addEventListener('ended', () => {
            <?php if ($nextFile): ?>
                window.location.href = 'video.php?file=<?php echo urlencode($nextFile); ?>';
            <?php else: ?>
                alert('没有下一集了！');
            <?php endif; ?>
        });

        // 触摸事件：上下滑动切换视频
        let touchStartY = 0;
        let touchEndY = 0;

        document.addEventListener('touchstart', (e) => {
            touchStartY = e.changedTouches[0].screenY;
        });

        document.addEventListener('touchend', (e) => {
            touchEndY = e.changedTouches[0].screenY;
            handleGesture();
        });

        function handleGesture() {
            if (touchEndY < touchStartY - 50) {
                // 向上滑动，跳转到下一集
                <?php if ($nextFile): ?>
                    window.location.href = 'video.php?file=<?php echo urlencode($nextFile); ?>';
                <?php else: ?>
                    alert('没有下一集了！');
                <?php endif; ?>
            }
            if (touchEndY > touchStartY + 50) {
                // 向下滑动，跳转到上一集
                <?php if ($prevFile): ?>
                    window.location.href = 'video.php?file=<?php echo urlencode($prevFile); ?>';
                <?php else: ?>
                    alert('没有上一集了！');
                <?php endif; ?>
            }
        }
    </script>
</body>
</html>
